# Copyright (c) 2021, InfluxFramework LLC
# License: MIT. See LICENSE
import json

import influxframework
from influxframework import _
from influxframework.utils import cint, flt

no_cache = 1

expected_keys = (
	"amount",
	"title",
	"description",
	"reference_doctype",
	"reference_docname",
	"payer_name",
	"payer_email",
	"order_id",
	"currency",
)


def get_context(context):
	context.no_cache = 1
	context.api_key = get_api_key()

	try:
		doc = influxframework.get_doc("Integration Request", influxframework.form_dict["token"])
		payment_details = json.loads(doc.data)

		for key in expected_keys:
			context[key] = payment_details[key]

		context["token"] = influxframework.form_dict["token"]
		context["amount"] = flt(context["amount"])
		context["subscription_id"] = (
			payment_details["subscription_id"] if payment_details.get("subscription_id") else ""
		)

	except Exception as e:
		influxframework.redirect_to_message(
			_("Invalid Token"),
			_("Seems token you are using is invalid!"),
			http_status_code=400,
			indicator_color="red",
		)

		influxframework.local.flags.redirect_location = influxframework.local.response.location
		raise influxframework.Redirect


def get_api_key():
	api_key = influxframework.db.get_single_value("Razorpay Settings", "api_key")
	if cint(influxframework.form_dict.get("use_sandbox")):
		api_key = influxframework.conf.sandbox_api_key

	return api_key


@influxframework.whitelist(allow_guest=True)
def make_payment(
	razorpay_payment_id, options, reference_doctype, reference_docname, token
):
	data = {}

	if isinstance(options, str):
		data = json.loads(options)

	data.update(
		{
			"razorpay_payment_id": razorpay_payment_id,
			"reference_docname": reference_docname,
			"reference_doctype": reference_doctype,
			"token": token,
		}
	)

	data = influxframework.get_doc("Razorpay Settings").create_request(data)
	influxframework.db.commit()
	return data
